==> k4de-0.3.0.tgz: k4de-0.3.0/src/kde/texture/imagemapdialog.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** imagemapdialog.h
*/
#ifndef __ImageMapWidget_H__
#define __ImageMapWidget_H__


#include <qwidget.h>
#include <qgroupbox.h>
#include <qpainter.h>
#include <qcolor.h>
#include <kcolorbtn.h>
#include <qdialog.h>
#include <qlineedit.h>
#include <qcheckbox.h>

#include <color.h>
#include <qcolor.h>
#include "../misc/spinbox.h"
#include "../widgets/getfilewidget.h"
#include "../../3d/textures/imagemap.h"


class ImageMapWidget : public QWidget
{
Q_OBJECT
protected:
	GetFileWidget		*filewidget;

	QLineEdit		*name;
	QComboBox		*mapping,*interpolate;
	QLabel			*maplabel,*interpolatelabel,*nameLabel;
	QCheckBox		*once;
	SpinBox			*filter, *transmit;
	imageMap		*im;
	bitmapmodifier		*bmm;
	QCheckBox		*active;

public:

	ImageMapWidget(QWidget *p, imageMap *);
	~ImageMapWidget();
	void getImageMap();

	int width();
	int height();

protected:
	void	paintEvent(QPaintEvent*);


};

//----------------------------------------------

class ImageMapDialog : public QDialog
{
Q_OBJECT
protected:

	QPushButton		*ok,*cancel;
	ImageMapWidget		*pw;

public:

	ImageMapDialog(QWidget *p, imageMap *);
	~ImageMapDialog();

protected:
	void	paintEvent(QPaintEvent*);
public slots:
	void okayPressed();
	void cancelPressed();
};



#endif

==> k4de-0.4.0.tgz: k4de-0.4.0/src/kde/texture/imagemapdialog.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** imagemapdialog.h
*/
#ifndef __ImageMapWidget_H__
#define __ImageMapWidget_H__


#include <qwidget.h>
#include <qgroupbox.h>
#include <qpainter.h>
#include <qdialog.h>
#include <qlineedit.h>
#include <qcheckbox.h>

#include "../misc/image.h"
#include <color.h>
#include <qcolor.h>
#include "../widgets/spinbox.h"
#include "../widgets/getfilewidget.h"
#include "../../3d/textures/imagemap.h"
#include "texturebasewidget.h"
#include "texturewidgetbase.h"
#include "../misc/image.h"

class ImageMapWidget : public TextureWidgetBase
{
Q_OBJECT
protected:
	GetFileWidget		*filewidget;

	Image	               *imgDat;
	QComboBox		*mapping,*interpolate;
	QLabel			*maplabel,*interpolatelabel,*nameLabel;

	QCheckBox		*once;
	SpinBox			*filter, *transmit;
	imageMap		*im;
	bitmapmodifier		*bmm;
	TextureBaseWidget	*tbasew;
	QSize			qs;

public:

	ImageMapWidget(QWidget *p, imageMap *);
	~ImageMapWidget();
	void getValue();

	Image 	*getImage();
	void	setImage(char *, int l);
	
	virtual QSize	sizeHint() const;

protected:
	void	paintEvent(QPaintEvent*);

protected slots:
	void	newImage();

};

//----------------------------------------------

class ImageMapDialog : public QDialog
{
Q_OBJECT
protected:

	QPushButton		*ok,*cancel;
	ImageMapWidget		*pw;

public:

	ImageMapDialog(QWidget *p, imageMap *);
	~ImageMapDialog();

protected:
	void	paintEvent(QPaintEvent*);
public slots:
	void okayPressed();
	void cancelPressed();
};



#endif
